/****************************************************************************
** Meta object code from reading C++ file 'expression.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../cantor-26.04.2/src/lib/expression.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'expression.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Cantor10ExpressionE_t {};
} // unnamed namespace

template <> constexpr inline auto Cantor::Expression::qt_create_metaobjectdata<qt_meta_tag_ZN6Cantor10ExpressionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Cantor::Expression",
        "idChanged",
        "",
        "gotResult",
        "resultsCleared",
        "resultRemoved",
        "index",
        "resultReplaced",
        "statusChanged",
        "Cantor::Expression::Status",
        "expressionFinished",
        "needsAdditionalInformation",
        "question"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'idChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'gotResult'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'resultsCleared'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'resultRemoved'
        QtMocHelpers::SignalData<void(int)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Signal 'resultReplaced'
        QtMocHelpers::SignalData<void(int)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Signal 'statusChanged'
        QtMocHelpers::SignalData<void(Cantor::Expression::Status)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 2 },
        }}),
        // Signal 'expressionFinished'
        QtMocHelpers::SignalData<void(Cantor::Expression::Status)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 2 },
        }}),
        // Signal 'needsAdditionalInformation'
        QtMocHelpers::SignalData<void(const QString &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Expression, qt_meta_tag_ZN6Cantor10ExpressionE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Cantor::Expression::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Cantor10ExpressionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Cantor10ExpressionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Cantor10ExpressionE_t>.metaTypes,
    nullptr
} };

void Cantor::Expression::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Expression *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->idChanged(); break;
        case 1: _t->gotResult(); break;
        case 2: _t->resultsCleared(); break;
        case 3: _t->resultRemoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->resultReplaced((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->statusChanged((*reinterpret_cast<std::add_pointer_t<Cantor::Expression::Status>>(_a[1]))); break;
        case 6: _t->expressionFinished((*reinterpret_cast<std::add_pointer_t<Cantor::Expression::Status>>(_a[1]))); break;
        case 7: _t->needsAdditionalInformation((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Expression::*)()>(_a, &Expression::idChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Expression::*)()>(_a, &Expression::gotResult, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Expression::*)()>(_a, &Expression::resultsCleared, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Expression::*)(int )>(_a, &Expression::resultRemoved, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Expression::*)(int )>(_a, &Expression::resultReplaced, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Expression::*)(Cantor::Expression::Status )>(_a, &Expression::statusChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Expression::*)(Cantor::Expression::Status )>(_a, &Expression::expressionFinished, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Expression::*)(const QString & )>(_a, &Expression::needsAdditionalInformation, 7))
            return;
    }
}

const QMetaObject *Cantor::Expression::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Cantor::Expression::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Cantor10ExpressionE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Cantor::Expression::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void Cantor::Expression::idChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Cantor::Expression::gotResult()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Cantor::Expression::resultsCleared()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Cantor::Expression::resultRemoved(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Cantor::Expression::resultReplaced(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Cantor::Expression::statusChanged(Cantor::Expression::Status _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Cantor::Expression::expressionFinished(Cantor::Expression::Status _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Cantor::Expression::needsAdditionalInformation(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}
QT_WARNING_POP
